cis_config: Class Members

cis_config

Here is a list of all documented class members with links to the class documentation for each member:

### - _ -

- _destroy_pi() : CisInput , CisOutput , CisRpc

### - a -

- address : comm_head_t , comm_t
- always_send_header : comm_t
- as_array : comm_head_t

### - b -

- bodybeg : comm_head_t
- bodysiz : comm_head_t

### - c -

- call() : CisRpcClient
- CisAsciiArrayInput() : CisAsciiArrayInput
- CisAsciiArrayInput_local() : CisAsciiArrayInput_local
- CisAsciiArrayOutput() : CisAsciiArrayOutput
- CisAsciiArrayOutput_local() : CisAsciiArrayOutput_local
- CisAsciiFileInput() : CisAsciiFileInput
- CisAsciiFileInput_local() : CisAsciiFileInput_local
- CisAsciiFileOutput() : CisAsciiFileOutput
- CisAsciiFileOutput_local() : CisAsciiFileOutput_local
- CisAsciiTableInput() : CisAsciiTableInput
- CisAsciiTableInput_local() : CisAsciiTableInput_local
- CisAsciiTableOutput() : CisAsciiTableOutput
- CisAsciiTableOutput_local() : CisAsciiTableOutput_local
- CisInput() : CisInput
- CisObjInput() : CisObjInput
- CisObjOutput() : CisObjOutput
- CisOutput() : CisOutput
- CisPlyInput() : CisPlyInput
- CisPlyOutput() : CisPlyOutput
- CisRpc() : CisRpc
- CisRpcClient() : CisRpcClient
- CisRpcServer() : CisRpcServer
- column : asciiTable_t
- comment : asciiFile_t

### - d -

- direction : comm_t

### - f -

- f : asciiTable_t
- face_normals : obj_t
- face_texcoords : obj_t
- faces : obj_t , ply_t
- fd : asciiFile_t
- field_names : comm_head_t
- field_units : comm_head_t
- filepath : asciiFile_t
- format_siz : asciiTable_t
- format_str : asciiTable_t , comm_head_t
- format_typ : asciiTable_t

### - h -

- handle : comm_t

### - i -

- id : comm_head_t
- index_in_register : comm_t
- info : comm_t , seri_t
- io_mode : asciiFile_t
- is_file : comm_t
- is_work_comm : comm_t

### - l -

- last_send : comm_t

### - m -

- material : obj_t
- maxMsgSize : comm_t
- multipart : comm_head_t

### - n -

- name : comm_t
- ncols : asciiTable_t
- newline : asciiFile_t
- nface : obj_t , ply_t
- nnorm : obj_t
- normals : obj_t
- ntexc : obj_t
- nvert : obj_t , ply_t
- nvert_in_face : ply_t

### - p -

- pi() : CisInput , CisOutput , CisRpc

### - r -

- recv() : CisInput , CisRpc
- recv_eof : comm_t
- recv_line() : CisAsciiFileInput
- recv_nolimit() : CisInput
- reply : comm_t
- request_id : comm_head_t
- response_address : comm_head_t
- row_siz : asciiTable_t

### - s -

- send() : CisOutput , CisRpc
- send_eof() : CisOutput
- send_line() : CisAsciiFileOutput
- send_nolimit() : CisOutput
- sent_eof : comm_t
- serializer : comm_t
- serializer_type : comm_head_t
- size : comm_head_t
- size_info : seri_t
- status : asciiTable_t

### - t -

- texcoords : obj_t
- type : comm_t , seri_t

### - u -

- used : comm_t

### - v -

- valid : comm_head_t , comm_t
- vertex_colors : obj_t , ply_t
- vertices : obj_t , ply_t

### - z -

- zmq_reply : comm_head_t
- zmq_reply_worker : comm_head_t

### - ~ -

- ~CisInput() : CisInput
- ~CisOutput() : CisOutput
- ~CisRpc() : CisRpc
- ~CisRpcClient() : CisRpcClient
- ~CisRpcServer() : CisRpcServer